get_senate_cloture_votes() returns a tibble of the number of cloture motions,
cloture votes, and successful cloture votes in the Senate during each Congress
since 1917.
Value
A tibble with the number of cloture motions, cloture votes, and successful cloture votes in each Congress.
Details
The data is sourced from the official Senate website, specifically https://www.senate.gov/legislative/cloture/clotureCounts.htm.